==> libstdc++-2.90.3.tar.bz2: libstdc++-2.90.3/src/stdstreams.cc <==

// Copyright (C) 1997-1999 Cygnus Solutions
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.

// XXX broken: these must be arranged to be initialized
//     before any other "static initializers" get executed.

#include <bits/std_iostream.h>
#include <bits/std_fstream.h>

namespace std {

#if 1
  istream cin (new filebuf("stdin", ios_base::in));
  ostream cout(new filebuf("stdout", ios_base::out));
  ostream cerr(new filebuf("stderr", ios_base::out));
  ostream clog(new filebuf("stderr", ios_base::out));
#else
  istream cin (new filebuf);
  ostream cout(new filebuf);
  ostream cerr(new filebuf);
  ostream clog(new filebuf);
#endif

#if _G_USE_WCHAR_T
  wistream wcin (new wfilebuf(0, ios_base::_S_fd_in));
  wostream wcout(new wfilebuf(1, ios_base::_S_fd_out));
  wostream wcerr(new wfilebuf(2, ios_base::_S_fd_out));
  wostream wclog(new wfilebuf(2, ios_base::_S_fd_out));
#endif

} // std::

==> libstdc++-2.90.5.tar.bz2: libstdc++-2.90.5/src/stdstreams.cc <==

// Copyright (C) 1997-1999 Cygnus Solutions
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.

#include <bits/std_istream.h>
#include <bits/std_ostream.h>
#include <bits/std_fstream.h>

namespace std {

  filebuf __cfileinit;
  istream cin(&__cfileinit);
  ostream cout(&__cfileinit);
  ostream cerr(&__cfileinit);
  ostream clog(&__cfileinit);
#ifdef _G_USE_WCHAR_T
  wfilebuf __wfileinit;
  wistream wcin(&__wfileinit);
  wostream wcout(&__wfileinit);
  wostream wcerr(&__wfileinit);
  wostream wclog(&__wfileinit);
#endif
 
} // std
